@@ -2,7 +2,7 @@
 # crypto and anonymity library.
 #
 # Licensed under the AGPLv3: https://www.gnu.org/licenses/agpl-3.0.html
-# Copyright © 2019-2021 Gonzo Investigatory Journalism Agency, LLC
+# Copyright © 2019-2021 Gonzo Investigative Journalism Agency, LLC
 #            <gonzo.development@protonmail.ch>
 #           © 2019-2021 Richard Machado <rmlibre@riseup.net>
 # All rights reserved.
@@ -12,16 +12,27 @@
 from init_tests import *
 
 
-__exports = set()
+__exports = []
+
+
+from test_misc_in_generics import *
+for variable in __all__:
+    __exports.append(variable)
+
+
+from test_BytesIO import *
+for variable in __all__:
+    __exports.append(variable)
 
 
 from test_Comprende import *
 for variable in __all__:
-    __exports.add(variable)
+    __exports.append(variable)
 
 
-__all__ = list(__exports)
+__all__ = __exports
+__exports = set(__exports)
 
 
-assert len(__all__) == len(__exports), "duplicated tests!!!"
+assert not __exports.difference(__all__), "duplicated tests!!!"
 
