@@ -2,7 +2,7 @@
 # crypto and anonymity library.
 #
 # Licensed under the AGPLv3: https://www.gnu.org/licenses/agpl-3.0.html
-# Copyright © 2019-2021 Gonzo Investigatory Journalism Agency, LLC
+# Copyright © 2019-2021 Gonzo Investigative Journalism Agency, LLC
 #            <gonzo.development@protonmail.ch>
 #           © 2019-2021 Richard Machado <rmlibre@riseup.net>
 # All rights reserved.
@@ -30,165 +30,168 @@ def test_datastream_limits():
         keystream = akeys(key, salt=salt)
         validator = StreamHMAC(key, salt=salt).for_encryption()
         run(pad.axor(ainvalid_size_datastream, key=keystream, validator=validator)[100]())
-    except ValueError:
+    except ValueError as e:
         pass
     else:
-        raise AssertionError
+        raise AssertionError("A cipher block exceeded 256 bytes", e)
 
     try:
         keystream = keys(key, salt=salt)
         validator = StreamHMAC(key, salt=salt).for_encryption()
         pad.xor(invalid_size_datastream, key=keystream, validator=validator)[100]()
-    except ValueError:
+    except ValueError as e:
         pass
     else:
-        raise AssertionError
+        raise AssertionError("A cipher block exceeded 256 bytes", e)
 
     try:
+        run(ainvalid_size_datastream.areset())
         keystream = abytes_keys(key, salt=salt)
         validator = StreamHMAC(key, salt=salt).for_encryption()
         run(pad.abytes_xor(ainvalid_size_datastream, key=keystream, validator=validator)[100]())
-    except ValueError:
+    except ValueError as e:
         pass
     else:
-        raise AssertionError
+        raise AssertionError("A cipher block exceeded 256 bytes", e)
 
     try:
+        invalid_size_datastream.reset()
         keystream = bytes_keys(key, salt=salt)
         validator = StreamHMAC(key, salt=salt).for_encryption()
         pad.bytes_xor(invalid_size_datastream, key=keystream, validator=validator)[100]()
-    except ValueError:
+    except ValueError as e:
         pass
     else:
-        raise AssertionError
+        raise AssertionError("A cipher block exceeded 256 bytes", e)
 
 
 def test_keys_limits():
     try:
         run(akeys(key=None)[100]())
-    except ValueError:
+    except ValueError as e:
         pass
     else:
-        raise AssertionError
+        raise AssertionError("A falsey key was used", e)
 
     try:
         keys(key=None)[100]()
-    except ValueError:
+    except ValueError as e:
         pass
     else:
-        raise AssertionError
+        raise AssertionError("A falsey key was used", e)
 
     try:
         run(abytes_keys(key=None)[100]())
-    except ValueError:
+    except ValueError as e:
         pass
     else:
-        raise AssertionError
+        raise AssertionError("A falsey key was used", e)
 
     try:
         bytes_keys(key=None)[100]()
-    except ValueError:
+    except ValueError as e:
         pass
     else:
-        raise AssertionError
+        raise AssertionError("A falsey key was used", e)
 
 
 def test_key_limits():
     try:
         run(pad.apadding_key(key=None, salt=salt))
-    except ValueError:
+    except ValueError as e:
         pass
     else:
-        raise AssertionError
+        raise AssertionError("A falsey key was used", e)
 
     try:
         pad.padding_key(key=None, salt=salt)
-    except ValueError:
+    except ValueError as e:
         pass
     else:
-        raise AssertionError
+        raise AssertionError("A falsey key was used", e)
 
     try:
         run(pad.apadding_key(salt=None))
-    except ValueError:
+    except ValueError as e:
         pass
     else:
-        raise AssertionError
+        raise AssertionError("A falsey salt was used", e)
 
     try:
         pad.padding_key(salt=None)
-    except ValueError:
+    except ValueError as e:
         pass
     else:
-        raise AssertionError
+        raise AssertionError("A falsey salt was used", e)
 
     try:
         run(pad.apadding_key(salt=csprng()))
-    except ValueError:
+    except ValueError as e:
         pass
     else:
-        raise AssertionError("Salt isn't a 32 byte hex string")
+        raise AssertionError("Salt isn't a 32 byte hex string", e)
 
     try:
         pad.padding_key(salt=csprng())
-    except ValueError:
+    except ValueError as e:
         pass
     else:
-        raise AssertionError("Salt isn't a 32 byte hex string")
+        raise AssertionError("Salt isn't a 32 byte hex string", e)
 
     try:
         run(pad.apadding_key(salt=csprbg()))
-    except ValueError:
+    except ValueError as e:
         pass
     else:
-        raise AssertionError("Salt isn't a 32 byte hex string")
+        raise AssertionError("Salt isn't a 32 byte hex string", e)
 
     try:
         pad.padding_key(salt=csprbg())
-    except ValueError:
+    except ValueError as e:
         pass
     else:
-        raise AssertionError("Salt isn't a 32 byte hex string")
+        raise AssertionError("Salt isn't a 32 byte hex string", e)
 
 
 def test_missing_Passcrypt_lines():
-    pcrypt = Passcrypt()
-    pcrypt(key, salt, **passcrypt_settings)
+    pcrypt = Passcrypt(**passcrypt_settings)
+    pcrypt.new(key, salt)
     pcrypt._passcrypt(key, salt, **passcrypt_settings)
-    run(pcrypt(key, salt, aio=True, **passcrypt_settings))
+    run(pcrypt.anew(key, salt))
     run(pcrypt._apasscrypt(key, salt, **passcrypt_settings))
 
     try:
-        run(pcrypt(None, salt, aio=True, **passcrypt_settings))
-    except ValueError:
+        run(pcrypt.anew(None, salt))
+    except ValueError as e:
         pass
     else:
-        raise AssertionError
+        raise AssertionError("Empty password was allowed.", e)
 
     try:
-        pcrypt(key, None, **passcrypt_settings)
-    except ValueError:
+        pcrypt.new(key, None)
+    except ValueError as e:
         pass
     else:
-        raise AssertionError
+        raise AssertionError("Empty salt was allowed.", e)
 
     try:
-        run(pcrypt(key, salt, aio=True, kb=255, hardness=256))
-    except ValueError:
+        run(pcrypt.anew(key, salt, kb=255, hardness=256))
+    except ValueError as e:
         pass
     else:
-        raise AssertionError
+        raise AssertionError("A `kb` cost below 256 was allowed.", e)
 
     try:
-        pcrypt(key, salt, kb=256, hardness=255)
-    except ValueError:
+        pcrypt.new(key, salt, kb=256, hardness=255)
+    except ValueError as e:
         pass
     else:
-        raise AssertionError
+        raise AssertionError("A `hardness` below 256 was allowed.", e)
 
     try:
-        pcrypt(key, salt, kb=256, cpu=1, hardness=256)
-    except ValueError:
+        pcrypt.new(key, salt, kb=256, cpu=1, hardness=256)
+    except ValueError as e:
         pass
     else:
-        raise AssertionError
+        raise AssertionError("A `cpu` cost below 2 was allowed.", e)
+
